/* Forecast Preparation */

/* you should probably isolate a set of retailers 
 * for which you are going to query forecast values.
 * These can be set up by isolating Q7s, Q9s and Q10s of interest
 * and determining the retailers associated with the Customer members in each.
 * That will constrain the size of the intermediate tables considerably.
 *
 * The following template assumes you have done so; replace $FCST_RETAILERS
 * by a set of retailer names (e.g. 'RWSN332VTEJS', 'A3UND94NSDKS') in the template
 */

delete from FcstRetailer1996Tmp
;

insert into FcstRetailer1996Tmp (
	Retailer_level ,
	UnitsSold ,
	DollarSales,
	DollarCost
)
select
	a.Retailer_level ,
	a.UnitsSold ,
	a.DollarSales,
	a.DollarCost
from 
	Fcst1996Retailer a
where
	a.retailer_level in ($FCST_RETAILERS)
;

commit
;

delete from Plan1996RetailerTmp
;

insert into Plan1996RetailerTmp (
	Retailer_level ,
	UnitsSold ,
	DollarSales,
	DollarCost 
)
select
	a.Retailer_level ,
	a.UnitsSold ,
	a.DollarSales,
	a.DollarCost
from 
	Plan1996Retailer a
where
	a.retailer_level in ($FCST_RETAILERS)
;

commit
;

delete from FcstMonthRetailer1996
;

INSERT INTO FcstMonthRetailer1996 (
	Retailer_level,
	Time_level   ,
	UnitsSold,
	DollarSales,
	DollarCost
)
SELECT
	custlevel.retailer_level,
	b.time_level,
	sum (a.UnitsSold * b.UnitsSold / c.UnitsSold) as UnitsSold,
	sum (a.DollarSales * b.DollarSales / c.DollarSales) as DollarSales, 
	sum (a.DollarCost * b.DollarCost / c.DollarCost) as DollarCost
FROM
	FcstRetailer1996Tmp a, planvars b, Plan1996RetailerTmp c, custlevel
WHERE
	    a.retailer_level = c.retailer_level
	and a.retailer_level = custlevel.retailer_level
	and b.customer_level = custlevel.store_level
	and c.retailer_level = custlevel.retailer_level
GROUP BY
	custlevel.retailer_level,
	b.time_level
;

commit
;

/*-------------------------------*/

drop INDEX TAY96MS
;

drop INDEX SAY96MS
;

delete from ActYToD1996MonthStore
;


insert into ActYToD1996MonthStore (
	Store_level,
	time_level,
	UnitsSold,
	DollarSales,
	DollarCost
)
select
	a.customer_level,
	'199606',
	sum(a.unitssold) as UnitsSold,
	sum(a.dollarsales) as DollarSales,
	sum(a.DollarCost) as DollarCost 
from 
	actvars a, custlevel
where
	    a.time_level in (
    		'199601', '199602', '199603', '199604', '199605', '199606'
	    )
	and a.customer_level = custlevel.store_level
	and custlevel.retailer_level in ($FCST_RETAILERS)
group by 
	a.customer_level
;

commit
;

CREATE INDEX TAY96MS ON ActYToD1996MonthStore
(
	Time_level ASC
)
;

CREATE INDEX SAY96MS ON ActYToD1996MonthStore
(
	Store_level ASC
)
;

/*--------------------------------------*/

drop index R_ActYToD1996MonthRetailerTmp 
;

drop index T_ActYToD1996MonthRetailerTmp
;

delete from ActYToD1996MonthRetailerTmp
;

insert into ActYToD1996MonthRetailerTmp (
	Retailer_level,
	time_level,
	UnitsSold,
	DollarSales,
	DollarCost
)
select
	a.Retailer_level,
	a.time_level,
	a.UnitsSold,
	a.DollarSales,
	a.DollarCost
from
	ActYToD1996MonthRetailer a
;

commit work
;


create  index R_ActYToD1996MonthRetailerTmp on ActYToD1996MonthRetailerTmp (
	Retailer_level ASC
)
;

create  index T_ActYToD1996MonthRetailerTmp on ActYToD1996MonthRetailerTmp (
	time_level ASC
)


drop INDEX TFMS
;

drop INDEX RFMS
;

delete from FcstMonthStore
;

INSERT INTO FcstMonthStore (
	Store_level,
	Time_level,
	UnitsSold,
	DollarSales,
	DollarCost 
)
SELECT
	b.store_level,
	a.time_level,
	(a.UnitsSold * b.UnitsSold / c.UnitsSold) as UnitsSold,
	(a.DollarSales * b.DollarSales / c.DollarSales) as DollarSales,
	(a.DollarCost * b.DollarCost / c.DollarCost) as DollarCost 
from
	FcstMonthRetailer1996 a, ActYToD1996MonthStore b, 
	ActYToD1996MonthRetailerTmp c, custlevel
where
	    a.retailer_level = c.retailer_level
	and a.retailer_level = custlevel.retailer_level
	and c.retailer_level = custlevel.retailer_level
	and b.store_level = custlevel.store_level
;

commit work
;


CREATE INDEX TFMS ON FcstMonthStore
(
	Time_level ASC
)
;

CREATE INDEX RFMS ON FcstMonthStore
(
	Store_level ASC
)
;


drop index P_PlanYToD1996MonthStoreP
;
drop index T_PlanYToD1996MonthStoreP
;
drop index S_PlanYToD1996MonthStoreP
;
delete from PlanYToD1996MonthStoreProduct
;

insert into PlanYToD1996MonthStoreProduct (
	Product_level,
	Store_level,
	time_level,
	UnitsSold,
	DollarSales,
	DollarCost 
)
select
	a.product_level,
	a.customer_level,
	'199606',
	sum(a.unitssold) as UnitsSold,
	sum(a.dollarsales) as DollarSales,
	sum(a.DollarCost) as DollarCost
from 
	planvars a, custlevel
where
	a.time_level in (
   		'199601', '199602', '199603', '199604', '199605', '199606'
	)
	and a.customer_level = custlevel.store_level
	and custlevel.retailer_level in ($FCST_RETAILERS)
group by 
	a.product_level,
	a.customer_level
;

commit
;


create index P_PlanYToD1996MonthStoreP on PlanYToD1996MonthStoreProduct (
	 Product_level ASC
)
;

create index T_PlanYToD1996MonthStoreP on PlanYToD1996MonthStoreProduct (
	 Time_level ASC
)
;

create index S_PlanYToD1996MonthStoreP on PlanYToD1996MonthStoreProduct (
	 Store_level ASC
)
;

DROP index T_PlanYToD1996MonthStoreTmp 
;
DROP index S_PlanYToD1996MonthStoreTmp
;
delete from PlanYToD1996MonthStoreTmp
;
commit
;


insert into PlanYToD1996MonthStoreTmp (
	Store_level,
	Time_level,
	UnitsSold,
	DollarSales,
	DollarCost 
)
select
	a.store_level,
	a.Time_level,
	a.UnitsSold,
	a.DollarSales,
	a.DollarCost
from
	PlanYToD1996MonthStore a
;

commit
;

create  index T_PlanYToD1996MonthStoreTmp on PlanYToD1996MonthStoreTmp (
	Time_level ASC
)
;

create  index S_PlanYToD1996MonthStoreTmp on PlanYToD1996MonthStoreTmp (
	Store_level ASC
)
;

commit
;


/* Final allocation step here! */

delete from FcstMonthStoreProduct
;

INSERT INTO FcstMonthStoreProduct (
	Product_level,
	Store_level,
	Time_level,
	UnitsSold,
	DollarSales,
	DollarCost
)
SELECT
	b.product_level,
	a.store_level,
	a.time_level,
	(a.UnitsSold * b.UnitsSold / c.UnitsSold) as UnitsSold,
	(a.DollarSales * b.DollarSales / c.DollarSales) as DollarSales,
	(a.DollarCost * b.DollarCost / c.DollarCost) as DollarCost 
FROM
	FcstMonthStore a, PlanYToD1996MonthStoreProd b, PlanYtod1996MonthStoreTmp c
WHERE
	    a.store_level = b.store_level
	and a.store_level = c.store_level
	and b.store_level = c.store_level
;

commit;

/* end of SQL */
